==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/imprisoned/dialogs_pl.lua <==

dialogId("ncp-m-tesno0", "font_small", "Look, how I am supposed to get out of here?")
dialogStr("I jak ja mam stąd wypłynąć?")


dialogId("ncp-m-tesno1", "font_small", "It`s quite tight in here.")
dialogStr("Trochę tu ciasno.")


dialogId("ncp-v-dostala", "font_big", "How did you manage to get there?")
dialogStr("Jak tam wlazłaś?")


dialogId("ncp-v-sasanka", "font_big", "Stop playing with anemones and help me to get us out of here.")
dialogStr("Zamiast się bawić z ukwiałami, lepiej byś mi pomogła nas stąd wydostać.")


dialogId("ncp-m-nekoukej", "font_small", "Don`t be surprised.")
dialogStr("Żebyś się nie zdziwił.")


dialogId("ncp-m-komari", "font_small", "There are so many corals here...")
dialogStr("Tyle tu kalorii...")


dialogId("ncp-v-ceho", "font_big", "What?")
dialogStr("Czego?")


dialogId("ncp-m-koraly", "font_small", "So many corals. Are you deaf or what?")
dialogStr("No korali, głuchy jesteś?")


dialogId("ncp-m-tvrdy", "font_small", "Oh my, this is a hard coral.")
dialogStr("Ale twardy koral.")


dialogId("ncp-v-mekky", "font_big", "Oh my, this is a soft coral.")
dialogStr("Ale miękki koral.")


dialogId("ncp-v-tak", "font_big", "So!")
dialogStr("Tak!")


dialogId("ncp-m-muzes", "font_small", "Now you can get out, can`t you?")
dialogStr("Teraz już możesz przepłynąć, prawda?")


dialogId("ncp-v-neprojedu", "font_big", "Hmm, I can`t get through here...")
dialogStr("Hmm, tędy nie przepłynę...")


dialogId("ncp-m-barvy", "font_small", "I love colors...")
dialogStr("Kocham kolory...")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/imprisoned/dialogs_pl.lua <==

dialogId("ncp-m-tesno0", "font_small", "Look, how I am supposed to get out of here?")
dialogStr("I jak ja mam stąd wypłynąć?")


dialogId("ncp-m-tesno1", "font_small", "It’s quite tight in here.")
dialogStr("Trochę tu ciasno.")


dialogId("ncp-v-dostala", "font_big", "How did you manage to get there?")
dialogStr("Jak tam wlazłaś?")


dialogId("ncp-v-sasanka", "font_big", "Stop playing with anemones and help me to get us out of here.")
dialogStr("Zamiast się bawić z ukwiałami, lepiej byś mi pomogła nas stąd wydostać.")


dialogId("ncp-m-nekoukej", "font_small", "Don’t be surprised.")
dialogStr("Żebyś się nie zdziwił.")


dialogId("ncp-m-komari", "font_small", "There are so many corals here...")
dialogStr("Tyle tu kalorii...")


dialogId("ncp-v-ceho", "font_big", "What?")
dialogStr("Czego?")


dialogId("ncp-m-koraly", "font_small", "So many corals. Are you deaf or what?")
dialogStr("No korali, głuchy jesteś?")


dialogId("ncp-m-tvrdy", "font_small", "Oh my, this is a hard coral.")
dialogStr("Ale twardy koral.")


dialogId("ncp-v-mekky", "font_big", "Oh my, this is a soft coral.")
dialogStr("Ale miękki koral.")


dialogId("ncp-v-tak", "font_big", "So!")
dialogStr("Tak!")


dialogId("ncp-m-muzes", "font_small", "Now you can get out, can’t you?")
dialogStr("Teraz już możesz przepłynąć, prawda?")


dialogId("ncp-v-neprojedu", "font_big", "Hmm, I can’t get through here...")
dialogStr("Hmm, tędy nie przepłynę...")


dialogId("ncp-m-barvy", "font_small", "I love colors...")
dialogStr("Kocham kolory...")
